unit StoredProc;

interface

uses
{$IFDEF FPC}
  LResources,
{$ENDIF}
{$IFDEF MSWINDOWS}
  Windows, Messages,
{$ENDIF}
  SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Db, Grids, DBGrids,  StdCtrls, ToolWin,
  ComCtrls, Buttons, PgDacVcl, DemoFrame, PgDacDemoForm,
  CRTypes, CRFunctions, {$IFNDEF FPC}MemDS,{$ELSE}MemDataSet,{$ENDIF}
  DBAccess, PgAccess;

type
  TStoredProcFrame = class(TDemoFrame)
    DataSource: TDataSource;
    PgStoredProc: TPgStoredProc;
    DBGrid: TDBGrid;
    ToolBar: TPanel;
    Panel1: TPanel;
    btOpen: TSpeedButton;
    btClose: TSpeedButton;
    btPrepare: TSpeedButton;
    btUnPrepare: TSpeedButton;
    btExecute: TSpeedButton;
    btPrepareSQL: TSpeedButton;
    btStartTransaction: TSpeedButton;
    Panel3: TPanel;
    Label1: TLabel;
    edStoredProcName: TComboBox;
    DBNavigator: TDBNavigator;
    btCommit: TSpeedButton;
    btRollback: TSpeedButton;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btPrepareClick(Sender: TObject);
    procedure btUnPrepareClick(Sender: TObject);
    procedure btExecuteClick(Sender: TObject);
    procedure btPrepareSQLClick(Sender: TObject);
    procedure edStoredProcNameExit(Sender: TObject);
    procedure edStoredProcNameDropDown(Sender: TObject);
    procedure btStartTransactionClick(Sender: TObject);
    procedure btCommitClick(Sender: TObject);
    procedure btRollbackClick(Sender: TObject);
  private
    { Private declarations }
    procedure ShowState;
    procedure AssignProperties;    
  public
    // Demo management
    procedure Initialize; override;
    procedure SetDebug(Value: boolean); override;
  end;

implementation

{$IFNDEF FPC}
{$IFDEF CLR}
{$R *.nfm}
{$ELSE}
{$R *.dfm}
{$ENDIF}
{$ENDIF}

procedure TStoredProcFrame.AssignProperties;
begin
  if Trim(PgStoredProc.StoredProcName) <> Trim(edStoredProcName.Text) then
    PgStoredProc.StoredProcName := edStoredProcName.Text;
  ShowState;  
end;

procedure TStoredProcFrame.ShowState;
var
  St: string;

  procedure AddSt(S:string);
  begin
    if St <> '' then
      St := St + ', ';
    St := St + S;
  end;

begin
  St := '';

  if PgStoredProc.Prepared then begin
    AddSt('Prepared');

    if PgStoredProc.IsQuery then
      AddSt('IsQuery');

  end;

  if PgStoredProc.Active then
    AddSt('Active')
  else
    AddSt('Inactive');

  PgDacForm.StatusBar.Panels[2].Text := St;
end;

procedure TStoredProcFrame.btOpenClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgStoredProc.Open;
  finally
    ShowState;
  end;
end;

procedure TStoredProcFrame.btCloseClick(Sender: TObject);
begin
  PgStoredProc.Close;
  ShowState;
end;

procedure TStoredProcFrame.btPrepareClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgStoredProc.Prepare;
  finally
    ShowState;
  end;
end;

procedure TStoredProcFrame.btUnPrepareClick(Sender: TObject);
begin
  PgStoredProc.UnPrepare;
  ShowState;
end;

procedure TStoredProcFrame.btExecuteClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgStoredProc.Execute;
  finally
    ShowState;
  end;
end;

procedure TStoredProcFrame.btPrepareSQLClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgStoredProc.PrepareSQL;
  finally
    ShowState;
  end;
end;

procedure TStoredProcFrame.edStoredProcNameExit(Sender: TObject);
begin
  AssignProperties;
end;

procedure TStoredProcFrame.edStoredProcNameDropDown(Sender: TObject);
var
  List: TStringList;
begin
  List := TStringList.Create;
  try
    PgStoredProc.Connection.GetStoredProcNames(List);
    AssignStrings(List, edStoredProcName.Items);
  finally
    List.Free;
  end;
end;

// Demo management
procedure TStoredProcFrame.Initialize;
begin
  inherited;
  PgStoredProc.Connection := Connection as TPgConnection;
  edStoredProcName.Text := PgStoredProc.StoredProcName;
  ShowState;
end;

procedure TStoredProcFrame.SetDebug(Value: boolean);
begin
  PgStoredProc.Debug := Value;
end;

procedure TStoredProcFrame.btStartTransactionClick(Sender: TObject);
begin
  PgStoredProc.Connection.StartTransaction;
end;

procedure TStoredProcFrame.btCommitClick(Sender: TObject);
begin
  PgStoredProc.Connection.Commit;
end;

procedure TStoredProcFrame.btRollbackClick(Sender: TObject);
begin
  PgStoredProc.Connection.Rollback;
end;

initialization
{$IFDEF FPC}
  {$i StoredProc.lrs}
{$ENDIF}
end.
