unit UpdateSQL;

interface

uses
{$IFDEF FPC}
  LResources,
{$ENDIF}
{$IFDEF MSWINDOWS}
  Windows, Messages,
{$ENDIF}
  SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Db, Grids, DBGrids,  StdCtrls, ToolWin, ComCtrls,
  Buttons, PgDACVcl, DemoFrame, PgDacDemoForm,
  {$IFNDEF FPC}MemDS{$ELSE}MemDataSet{$ENDIF}, DBAccess, PgAccess;

type
  TUpdateSQLFrame = class(TDemoFrame)
    PgQuery: TPgQuery;
    DataSource: TDataSource;
    PgUpdateSQL: TPgUpdateSQL;
    Panel5: TPanel;
    Panel2: TPanel;
    btOpen: TSpeedButton;
    btClose: TSpeedButton;
    btPrepare: TSpeedButton;
    btUnPrepare: TSpeedButton;
    btExecute: TSpeedButton;
    meSQL: TMemo;
    Splitter1: TSplitter;
    Panel3: TPanel;
    Panel1: TPanel;
    btRefreshRecord: TSpeedButton;
    DBNavigator1: TDBNavigator;
    DBGrid: TDBGrid;
    DeleteSQL: TPgSQL;
    InsertSQL: TPgSQL;
    ModifyQuery: TPgQuery;
    RefreshQuery: TPgQuery;
    Panel4: TPanel;
    cbDeleteObject: TCheckBox;
    cbInsertObject: TCheckBox;
    cbModifyObject: TCheckBox;
    cbRefreshObject: TCheckBox;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btPrepareClick(Sender: TObject);
    procedure btUnPrepareClick(Sender: TObject);
    procedure btExecuteClick(Sender: TObject);
    procedure meSQLExit(Sender: TObject);
    procedure btRefreshRecordClick(Sender: TObject);
    procedure cbDeleteObjectClick(Sender: TObject);
  private
    { Private declarations }
    procedure ShowState;
    procedure AssignProperties;
  public
    // Demo management
    procedure Initialize; override;
    procedure SetDebug(Value: boolean); override;
  end;

implementation

{$IFNDEF FPC}
{$IFDEF CLR}
{$R *.nfm}
{$ELSE}
{$R *.dfm}
{$ENDIF}
{$ENDIF}

procedure TUpdateSQLFrame.ShowState;
var
  St:string;

  procedure AddSt(S:string);
  begin
    if St <> '' then
      St:= St + ', ';
    St:= St + S;
  end;

begin
  St:= '';

  if PgQuery.Prepared then begin
    AddSt('Prepared');

    if PgQuery.IsQuery then
      AddSt('IsQuery');
  end;

  if PgQuery.Active then
    AddSt('Active')
  else
    AddSt('Inactive');

  if PgQuery.Executing then
    AddSt('Executing');

  if PgQuery.Fetching then
    AddSt('Fetching');

  PgDacForm.StatusBar.Panels[0].Text:= St;
end;

procedure TUpdateSQLFrame.AssignProperties;
begin
  if PgQuery.SQL.Text <> meSQL.Lines.Text then
    PgQuery.SQL.Assign(meSQL.Lines);
end;

procedure TUpdateSQLFrame.meSQLExit(Sender: TObject);
begin
  if Trim(PgQuery.SQL.Text) <> Trim(meSQL.Lines.Text) then
    PgQuery.SQL.Text:= meSQL.Lines.Text;
  ShowState;
end;

procedure TUpdateSQLFrame.btOpenClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgQuery.Open;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btCloseClick(Sender: TObject);
begin
  PgQuery.Close;
  ShowState;
end;

procedure TUpdateSQLFrame.btPrepareClick(Sender: TObject);
begin
  try
    AssignProperties;
    PgQuery.Prepare;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btUnPrepareClick(Sender: TObject);
begin
  PgQuery.UnPrepare;
  ShowState;
end;

procedure TUpdateSQLFrame.btExecuteClick(Sender: TObject);
begin
  try
    AssignProperties;  
    PgQuery.Execute;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btRefreshRecordClick(Sender: TObject);
begin
  PgQuery.RefreshRecord;
end;

// Demo management
procedure TUpdateSQLFrame.Initialize;
begin
  inherited;
  PgQuery.Connection := Connection as TPgConnection;
  meSQL.Lines.Assign(PgQuery.SQL);
  ShowState;
end;

procedure TUpdateSQLFrame.SetDebug(Value: boolean);
begin
  PgQuery.Debug:= Value;
end;

procedure TUpdateSQLFrame.cbDeleteObjectClick(Sender: TObject);
  function GetComponent(cbObject: TCheckBox; Component: TComponent): TComponent;
  begin
    if cbObject.Checked then
      Result := Component
    else
      Result := nil;
  end;
begin
  PgUpdateSQL.DeleteObject := GetComponent(cbDeleteObject, DeleteSQL);
  PgUpdateSQL.InsertObject := GetComponent(cbInsertObject, InsertSQL);
  PgUpdateSQL.ModifyObject := GetComponent(cbModifyObject, ModifyQuery);
  PgUpdateSQL.RefreshObject := GetComponent(cbRefreshObject, RefreshQuery);
end;

{$IFDEF FPC}
initialization
  {$i UpdateSQL.lrs}
{$ENDIF}
end.
